==> alibabacloud_cas20200407-1.3.0.tar.gz: alibabacloud_cas20200407-1.3.0/ChangeLog.md <==
2024-03-13 Version: 1.2.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudResources.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.


2024-02-27 Version: 1.1.0
- Support API CreateCsr.
- Support API DeleteCsr.
- Support API GetCsrDetail.
- Support API ListCsr.
- Support API UpdateCsr.
- Support API UploadCsr.


2024-02-23 Version: 1.0.16
- Generated python 2020-04-07 for cas.

2023-12-20 Version: 1.0.15
- Generated python 2020-04-07 for cas.

2023-12-19 Version: 1.0.14
- Generated python 2020-04-07 for cas.

2022-11-30 Version: 1.0.13
- Support resourceGroup.

2022-11-24 Version: 1.0.12
- Support deleteCertificate.

2022-11-17 Version: 1.0.11
- Support GetCertWarehouseQuota.

2022-11-07 Version: 1.0.9
- Support encrypt and decrypt.

2022-11-03 Version: 1.0.8
- Support encrypt and decrypt.

2022-09-23 Version: 1.0.7
- Support SSL Sign.

2022-09-15 Version: 1.0.6
- Support Certificate Warehouse.

2022-03-16 Version: 1.0.5
- Fixed ListUserCertificateOrder API response error bug.

2022-03-16 Version: 1.0.4
- Fixed ListUserCertificateOrder API response error bug.

2022-02-24 Version: 1.0.3
- Add ListUserCertificateOrder API.

2021-12-21 Version: 1.0.2
- Support New SDK.

2021-03-30 Version: 1.0.1
- Generated python 2020-04-07 for cas.

2020-12-29 Version: 1.0.0
- AMP Version Change.

==> alibabacloud_cas20200407-2.0.0.tar.gz: alibabacloud_cas20200407-2.0.0/ChangeLog.md <==
2024-08-21 Version: 1.7.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API MoveResourceGroup.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.
- Update API GetUserCertificateDetail: update response param.


2024-08-20 Version: 1.6.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API MoveResourceGroup.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.
- Update API GetUserCertificateDetail: update response param.


2024-08-13 Version: 1.5.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API MoveResourceGroup.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.
- Update API GetUserCertificateDetail: update response param.


2024-06-13 Version: 1.4.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API MoveResourceGroup.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.


2024-05-06 Version: 1.3.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeCloudResourceStatus.
- Support API DescribeDeploymentJob.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudAccess.
- Support API ListCloudResources.
- Support API ListContact.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API ListWorkerResource.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.


2024-03-13 Version: 1.2.0
- Support API CreateCsr.
- Support API CreateDeploymentJob.
- Support API DeleteCsr.
- Support API DeleteDeploymentJob.
- Support API DeleteWorkerResource.
- Support API DescribeDeploymentJobStatus.
- Support API GetCsrDetail.
- Support API ListCloudResources.
- Support API ListCsr.
- Support API ListDeploymentJob.
- Support API ListDeploymentJobCert.
- Support API ListDeploymentJobResource.
- Support API UpdateCsr.
- Support API UpdateDeploymentJob.
- Support API UpdateDeploymentJobStatus.
- Support API UpdateWorkerResourceStatus.
- Support API UploadCsr.


2024-02-27 Version: 1.1.0
- Support API CreateCsr.
- Support API DeleteCsr.
- Support API GetCsrDetail.
- Support API ListCsr.
- Support API UpdateCsr.
- Support API UploadCsr.


2024-02-23 Version: 1.0.16
- Generated python 2020-04-07 for cas.

2023-12-20 Version: 1.0.15
- Generated python 2020-04-07 for cas.

2023-12-19 Version: 1.0.14
- Generated python 2020-04-07 for cas.

2022-11-30 Version: 1.0.13
- Support resourceGroup.

2022-11-24 Version: 1.0.12
- Support deleteCertificate.

2022-11-17 Version: 1.0.11
- Support GetCertWarehouseQuota.

2022-11-07 Version: 1.0.9
- Support encrypt and decrypt.

2022-11-03 Version: 1.0.8
- Support encrypt and decrypt.

2022-09-23 Version: 1.0.7
- Support SSL Sign.

2022-09-15 Version: 1.0.6
- Support Certificate Warehouse.

2022-03-16 Version: 1.0.5
- Fixed ListUserCertificateOrder API response error bug.

2022-03-16 Version: 1.0.4
- Fixed ListUserCertificateOrder API response error bug.

2022-02-24 Version: 1.0.3
- Add ListUserCertificateOrder API.

2021-12-21 Version: 1.0.2
- Support New SDK.

2021-03-30 Version: 1.0.1
- Generated python 2020-04-07 for cas.

2020-12-29 Version: 1.0.0
- AMP Version Change.
